#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-quickcheck2
version:              0.3.0.7
visibility:           public
id:                   test-framework-quickcheck2-0.3.0.7-5cbCzyj0ZnF6R9rJoVWEbD
key:                  test-framework-quickcheck2-0.3.0.7-5cbCzyj0ZnF6R9rJoVWEbD
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://github.com/haskell/test-framework#readme
synopsis:             QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.

category:             Testing
abi:                  90bf28da65bd1b7b47e134ecde701437
exposed:              True
exposed-modules:      Test.Framework.Providers.QuickCheck2
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/test-framework-quickcheck2-0.3.0.7

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/test-framework-quickcheck2-0.3.0.7

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/test-framework-quickcheck2-0.3.0.7

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-quickcheck2
hs-libraries:         HStest-framework-quickcheck2-0.3.0.7-5cbCzyj0ZnF6R9rJoVWEbD
depends:
    QuickCheck-2.15.0.1-fyQWEOVjQY85EPR3Jn9YV base-4.18.2.1
    random-1.2.1.3-Bdym4wOOv4n4rVp69qUOL6
    test-framework-0.8.2.3-CEgrEpW2yDZJB5fsT6OA8a

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

